@@ -22,6 +22,7 @@ def run_kaks(sp_list,step1out,args,config,step4out,step5out,gene_pairs_idmap):
     KaKs_Calculator=config.get("software", "KaKs_Calculator")
     Kaks_aligncmd=config.get("software", "muscle")
     Epal2nal=config.get("software", "Epal2nal")
+    trimal=config.get("software", "trimal")
     step5_sh.writelines([   "perl ParaAT.pl -kaks "+KaKs_Calculator+op+" -h "+os.sep.join([step5out,"all_gene_pairs.list"])
                             +" -n "+os.sep.join([step5out,"all_cds.fa"])+" -a "+os.sep.join([step5out,'all_pep.fa'])+" -p "+str(args.t)+" -k -f axt -o "+os.sep.join([step5out,"all_gene_pairs_kaks"])+"\n",
                             "cd "+os.sep.join([step5out,"all_gene_pairs_kaks"])+"\n",
@@ -119,7 +120,7 @@ def sub_sh(pair,pepmap,cdsmap,KaKs_Calculator,Kaks_aligncmd,Epal2nal,op):
         logging.warn(pair[2]+"-"+pair[3]+".cds_aln is empty,Processing of this gene pair has been skipped, please check for special characters in the protein sequence")
         pass
     else:
-        trimal_stdout=subprocess.run("trimal -in "+pair[2]+"-"+pair[3]+".cds_aln -out "+pair[2]+"-"+pair[3]+".filted.cds_aln -automated1 -resoverlap 0.7 -seqoverlap 75",shell=True,stdout=subprocess.PIPE,stderr=subprocess.PIPE)
+        trimal_stdout=subprocess.run(trimal+" -in "+pair[2]+"-"+pair[3]+".cds_aln -out "+pair[2]+"-"+pair[3]+".filted.cds_aln -automated1 -resoverlap 0.7 -seqoverlap 75",shell=True,stdout=subprocess.PIPE,stderr=subprocess.PIPE)
         Fasta2AXT(pair[2]+"-"+pair[3]+".filted.cds_aln",pair[2]+"-"+pair[3]+".cds_aln.axt")
         kaks_stdout=subprocess.run(KaKs_Calculator+op+" -i "+pair[2]+"-"+pair[3]+".cds_aln.axt -o  "+pair[2]+"-"+pair[3]+".cds_aln.axt.kaks >> msg.kaks",shell=True,stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         axt2oneline((pair[2]+"-"+pair[3]+".cds_aln.axt"),(pair[2]+"-"+pair[3]+".one-line"))
