@@ -38,7 +38,7 @@ def cmd_check(cmd):
 
 def main():
     pwd= os.getcwd()
-    parser = argparse.ArgumentParser(description='Tree2GD:A pipeline for WGD V1.0.41')
+    parser = argparse.ArgumentParser(description='Tree2GD:A pipeline for WGD V1.0.42')
     parser.add_argument('-i', type=str, required=True, metavar='input_dir',help='The CDS and pep dir.')
     parser.add_argument('-tree', type=str, required=True, metavar='phytree.nwk',help='The phytree file.')
     parser.add_argument('-t', type=int,metavar='t',default='1', help='Thread num.default:1')
@@ -157,6 +157,9 @@ def main():
         Epal2nal=cf.get("software", "Epal2nal") if cf.has_option("software", "Epal2nal") and cf.get("software", "Epal2nal")!="" else os.sep.join([home_dir,"tree2gd","software", "Epal2nal.pl"])
         cmd_check(Epal2nal)
         cf.set("software", "Epal2nal",Epal2nal)
+        trimal=cf.get("software", "trimal") if cf.has_option("software", "trimal") and cf.get("software", "trimal")!="" else os.sep.join([home_dir,"tree2gd","software", "trimal"])
+        cmd_check(trimal)
+        cf.set("software", "trimal",trimal)
 
 
     if not os.path.exists(abs_out):
